import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, Tabs, Radio, DatePicker, message, Upload } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import moment from 'moment';
import router from 'umi/router';
import BuildSelect from '../../../../../components/SelectButton/BuildSelect'
import XForm, { FieldTypes } from '../../../../../components/XForm';
import Wangedit from '../../../../../components/Wangedit/Wangedit'
import request from '../../../../../utils/request'
import PosterBottom from '../../../../../assets/bottom.png'
import yinhao from '../../../../../assets/yinhao.png'
import ImageUploader from '../../../../../components/XForm/ImageUpload';
import logo from '../../../../../assets/logo.png';
import touxiang from '../../../../../assets/touxiang.jpg';
import poster1 from '../../../../../assets/poster1.png';
import poster2 from '../../../../../assets/poster2.png';

const { MonthPicker, RangePicker, WeekPicker } = DatePicker;
const { TextArea } = Input;

const Poster = props => {
  const [inputValue, changeInput] = useState('')
  const [textAreaValue, changeTextArea] = useState('')
  const [imgValue, changeImg] = useState('')
  const [posterId, setPosterId] = useState('')

  const { buildingId } = props.building

  if (buildingId) {
    // eslint-disable-next-line react-hooks/rules-of-hooks
    useEffect(() => {
      request({
        url: '/api/admin/poster',
        method: 'GET',
        params: { targetId: buildingId, targetType: 'building' },
      }).then(data => {
        console.log(data, '2222')
        if (data.length > 0) {
          setPosterId(data[0].posterId)
          changeImg(data[0].posterImg)
          changeTextArea(data[0].posterDescription)
          changeInput(data[0].posterTitle)
        }
      }).catch(err => {
        message.info(err.msg || err.message)
      })
    }, [])
  }

  const submitPoster = () => {
     if (buildingId) {
      if (posterId) {
        request({
          url: `/api/admin/poster/${posterId}`,
          method: 'PUT',
          data: { targetId: buildingId, targetType: 'building', posterImg: imgValue, posterTitle: inputValue, posterDescription: textAreaValue },
        }).then(() => {
          message.info('保存成功')
        }).catch(err => {
          message.info(err.msg || err.message)
        })
       } else {
        request({
          url: '/api/admin/poster',
          method: 'POST',
          data: { targetId: buildingId, targetType: 'building', posterImg: imgValue, posterTitle: inputValue, posterDescription: textAreaValue },
        }).then(data => {
          setPosterId(data.posterId)
          message.info('保存成功')
        }).catch(err => {
          message.info(err.msg || err.message)
        })
       }
     } else {
      message.warn('请先保存基本信息数据')
     }
  }

  return <div>
    <div style={{ display: 'flex' }}>
      <div style={{ width: '420px', height: '900px', display: 'inline-block', marginTop: '30px' }}>
        <div style={{ width: '375px', height: '785px', backgroundColor: '#fff', boxShadow: '0px 0px 16px 6px rgba(0,0,0,0.15)', position: 'relative', margin: '0 auto' }}>
          <img style={{ width: '100%', height: '300px' }} src={imgValue || poster1} alt="" />
          <div style={{ display: 'flex', alignItems: 'center', marginTop: '-24px' }}>
            <img style={{ width: '70px', height: '70px', border: '4px solid #fff', borderRadius: '35px', marginLeft: '16px' }} src={touxiang} alt="" />
            <span style={{ color: '#222', fontWeight: '600', margin: '24px 10px 0 14px', fontSize: '17px' }}>喵喵</span>
            <span style={{ color: '#999', marginTop: '25px', fontSize: '17px' }}>邀您阅读</span>
            <span style={{ color: '#999', margin: '25px 0 0 60px', fontSize: '17px' }}>2019.09.21</span>
          </div>
          <p style={{
            margin: '10px 20px', fontSize: '20px', color: '#222', fontWeight: '600',
            display: '-webkit-box', lineClamp: '3', height: '60px',
            WebkitLineClamp: '2',
            WebkitBoxOrient: 'vertical',
            overflow: 'hidden',
            textOverflow: 'ellipsis',
          }}>{inputValue || '海报标题'}</p>

          <img src={yinhao} style={{ width: '30px', marginLeft: '10px' }} alt="" />
          <p style={{
            margin: '16px 20px 28px 20px', fontSize: '17px', color: '#999',
            display: '-webkit-box', lineClamp: '3', height: '76px',
            WebkitLineClamp: '3',
            WebkitBoxOrient: 'vertical',
            overflow: 'hidden',
            textOverflow: 'ellipsis',
          }}>{textAreaValue || '海报描述'}</p>
          <img src={PosterBottom} style={{ width: '100%' }} alt="" />
        </div>
        <p style={{ textAlign: 'center', fontSize: '19px', color: '#666', marginTop: '30px' }}>海报模板</p>
      </div>

      <div >
        <div style={{ display: 'flex', width: '100%', margin: '60px 0' }}>
          <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>海报图片</p>
          <ImageUploader value={imgValue} onChange={e => changeImg(e)} />
        </div>
        <div style={{ display: 'flex', alignItems: 'center', width: '100%', marginBottom: '60px' }}>
          <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>海报标题</p>
          <Input style={{ width: '20vw' }} value={inputValue} placeholder="请输入海报标题" onChange={e => changeInput(e.target.value)} />
        </div>
        <div style={{ display: 'flex', margin: '10px 0 40px 0', width: '100%' }}>
          <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>海报描述</p>
          <TextArea rows={5} value={textAreaValue} onChange={e => changeTextArea(e.target.value)} />
        </div>

      </div>
    </div>
    <Button type="primary" onClick={submitPoster} style={{ margin: '40px 40px 40px 30vw' }}> 确定</Button>
    <Button onClick={() => router.go(-1)}>取消</Button>
  </div>
}

export default Poster
